@@ -65,7 +65,7 @@ require AutoLoader;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
-our $VERSION = '2.10';
+our $VERSION = '2.12';
 
 
 bootstrap Math::GMP $VERSION;
@@ -118,7 +118,7 @@ Math::GMP - High speed arbitrary size integer math
 
 =head1 VERSION
 
-version 2.10
+version 2.12
 
 =head1 SYNOPSIS
 
@@ -276,6 +276,23 @@ Returns the modular inverse of $x (mod $y), if defined. This currently
 returns 0 if there is no inverse (but that may change in the future).
 Behaviour is undefined when $y is 0.
 
+=head2 broot
+
+  my $x = Math::GMP->new(100);
+  my $root = $x->root(3);    # int(100 ** (1/3)) => 4
+  print $root;
+
+Returns the integer n'th root of its argument, given a positive integer n.
+
+=head2 brootrem
+
+  my $x = Math::GMP->new(100);
+  my($root, $rem) = $x->rootrem(3); # 4 ** 3 + 36 = 100
+  print "$x is $rem more than the cube of $root";
+
+Returns the integer n'th root of its argument, and the difference such that
+C< $root ** $n + $rem == $x >.
+
 =head2 bsqrt
 
   my $x = Math::GMP->new(6);
@@ -284,6 +301,32 @@ Behaviour is undefined when $y is 0.
 
 Returns the integer square root of its argument.
 
+=head2 bsqrtrem
+
+  my $x = Math::GMP->new(7);
+  my($root, $rem) = $x->sqrtrem(); # 2 ** 2 + 3 = 7
+  print "$x is $rem more than the square of $root";
+
+Returns the integer square root of its argument, and the difference such that
+C< $root ** 2 + $rem == $x >.
+
+=head2 is_perfect_power
+
+  my $x = Math::GMP->new(100);
+  my $is_power = $x->is_perfect_power();
+  print "$x is " . ($is_power ? "" : "not ") . "a perfect power";
+
+Returns C<TRUE> if its argument is a power, ie if there exist integers a
+and b with b > 1 such that C< $x == $a ** $b >.
+
+=head2 is_perfect_square
+
+  my $x = Math::GMP->new(100);
+  my $is_square = $x->is_perfect_square();
+  print "$x is " . ($is_square ? "" : "not ") . "a perfect square";
+
+Returns C<TRUE> if its argument is the square of an integer.
+
 =head2 legendre
 
   $x = Math::GMP->new(6);
@@ -351,6 +394,64 @@ Returns a string representation of the number in base $base.
 
 Returns a copy of $x that can be modified without affecting the original.
 
+=head2 my $verdict = $x->gmp_tstbit($bit_index);
+
+Returns whether or not bit No. $bit_index is 1 in $x.
+
+=head2 my $remainder = $dividend->mmod_gmp($divisor)
+
+  my $x = Math::GMP->new(2 . ('0' x 200) . 4);
+  my $y = Math::GMP->new(5);
+
+  my $ret = $x->mmod_gmp($y);
+  # $ret is now Math::GMP of 4.
+
+From the GMP documentation:
+
+Divide dividend and divisor and put the remainder in remainder. The remainder
+is always positive, and its value is less than the value of the divisor.
+
+=head2 my $result = $x->mod_2exp_gmp($shift);
+
+  my $x = Math::GMP->new(0b10001011);
+  my $ret = $x->mod_2exp_gmp(4);
+
+  # $ret is now Math::GMP of 0b1011
+
+Returns a Math::GMP object containing the lower $shift bits of $x (while not
+modifying $x).
+
+=head2 my $left_shifted = $x->mul_2exp_gmp($shift);
+
+  my $x = Math::GMP->new(0b10001011);
+  my $ret = $x->mul_2exp_gmp(4);
+
+  # $ret is now Math::GMP of 0b1000_1011_0000
+
+Returns a Math::GMP object containing $x shifted by $shift bits
+(where $shift is a plain integer).
+
+=head2 my $ret = $base->powm_gmp($exp, $mod);
+
+    my $base = Math::GMP->new(157);
+    my $exp = Math::GMP->new(100);
+    my $mod = Math::GMP->new(5013);
+
+    my $ret = $base->powm_gmp($exp, $mod);
+
+    # $ret is now (($base ** $exp) % $mod)
+
+Returns $base raised to the power of $exp modulo $mod.
+
+=head2 my $plain_int_ret = $x->sizeinbase_gmp($plain_int_base);
+
+Returns the size of $x in base $plain_int_base .
+
+=head2 my $int = $x->intify();
+
+Returns the value of the object as an unblessed (and limited-in-precision)
+integer.
+
 =head2 gcd()
 
 An alias to bgcd() .
@@ -367,6 +468,54 @@ For internal use. B<Do not use directly>.
 
 For internal use. B<Do not use directly>.
 
+=head2 new_from_scalar
+
+For internal use. B<Do not use directly>.
+
+=head2 new_from_scalar_with_base
+
+For internal use. B<Do not use directly>.
+
+=head2 op_add
+
+For internal use. B<Do not use directly>.
+
+=head2 op_div
+
+For internal use. B<Do not use directly>.
+
+=head2 op_eq
+
+For internal use. B<Do not use directly>.
+
+=head2 op_mod
+
+For internal use. B<Do not use directly>.
+
+=head2 op_mul
+
+For internal use. B<Do not use directly>.
+
+=head2 op_pow
+
+For internal use. B<Do not use directly>.
+
+=head2 op_spaceship
+
+For internal use. B<Do not use directly>.
+
+=head2 op_sub
+
+For internal use. B<Do not use directly>.
+
+=head2 stringify
+
+For internal use. B<Do not use directly>.
+
+=head2 uintify
+
+For internal use. B<Do not use directly>.
+
 =head1 BUGS
 
 As of version 1.0, Math::GMP is mostly compatible with the old
